==> digitalocean-api-client-2.13-sources.jar: com/myjeeva/digitalocean/pojo/TagDropletResource.java <==
/**
 * The MIT License
 * 
 * Copyright (c) 2013-2017 Jeevanandam M. (myjeeva.com)
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.myjeeva.digitalocean.pojo;

import org.apache.commons.lang3.builder.ReflectionToStringBuilder;

import com.google.gson.annotations.SerializedName;

/**
 * Represents the droplet resource a tag is attached on DigitalOcean.
 * 
 * @author Jeevanandam M. (jeeva@myjeeva.com)
 * 
 * @since v2.5
 */
public class TagDropletResource {

  private int count;

  @SerializedName("last_tagged")
  private Droplet lastTagged;

  @Override
  public String toString() {
    return ReflectionToStringBuilder.toString(this);
  }

  /**
   * @return the count
   */
  public int getCount() {
    return count;
  }

  /**
   * @param count the count to set
   */
  public void setCount(int count) {
    this.count = count;
  }

  /**
   * @return the lastTagged
   */
  public Droplet getLastTagged() {
    return lastTagged;
  }

  /**
   * @param lastTagged the lastTagged to set
   */
  public void setLastTagged(Droplet lastTagged) {
    this.lastTagged = lastTagged;
  }

}

==> digitalocean-api-client-2.17-sources.jar: com/myjeeva/digitalocean/pojo/TagDropletResource.java <==
/**
 * The MIT License
 * 
 * Copyright (c) 2013-2019 Jeevanandam M. (jeeva@myjeeva.com)
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.myjeeva.digitalocean.pojo;

import org.apache.commons.lang3.builder.ReflectionToStringBuilder;

import com.google.gson.annotations.SerializedName;

/**
 * Represents the droplet resource a tag is attached on DigitalOcean.
 * 
 * @author Jeevanandam M. (jeeva@myjeeva.com)
 * 
 * @since v2.5
 */
public class TagDropletResource {

  private int count;
  
  @SerializedName("last_tagged_uri")
  private String lastTaggedUri;

  @Deprecated
  @SerializedName("last_tagged")
  private Droplet lastTagged;

  @Override
  public String toString() {
    return ReflectionToStringBuilder.toString(this);
  }

  /**
   * @return the count
   */
  public int getCount() {
    return count;
  }

  /**
   * @param count the count to set
   */
  public void setCount(int count) {
    this.count = count;
  }

  /**
   * @return the lastTaggedUri
   */
  public String getLastTaggedUri() {
    return lastTaggedUri;
  }

  /**
   * @param lastTaggedUri the lastTaggedUri to set
   */
  public void setLastTaggedUri(String lastTaggedUri) {
    this.lastTaggedUri = lastTaggedUri;
  }

  /**
   * @return the lastTagged
   * 
   * <p>Deprecated: https://developers.digitalocean.com/documentation/changelog/api-v2/adding-tagged-uri/</p>
   */
  @Deprecated 
  public Droplet getLastTagged() {
    return lastTagged;
  }

  /**
   * @param lastTagged the lastTagged to set
   * 
   * <p>Deprecated: https://developers.digitalocean.com/documentation/changelog/api-v2/adding-tagged-uri/</p>
   */
  @Deprecated
  public void setLastTagged(Droplet lastTagged) {
    this.lastTagged = lastTagged;
  }

}
